@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Distribution;
 # ABSTRACT: A Distribution data object
-$MetaCPAN::Client::Distribution::VERSION = '1.022000'; # TRIAL
+$MetaCPAN::Client::Distribution::VERSION = '1.025000'; # TRIAL
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -43,27 +43,27 @@ MetaCPAN::Client::Distribution - A Distribution data object
 
 =head1 VERSION
 
-version 1.022000
+version 1.025000
+
+=head1 SYNOPSIS
+
+my $dist = $mcpan->distribution('MetaCPAN-Client');
 
 =head1 DESCRIPTION
 
-    my $dist = $mcpan->distribution('MetaCPAN-Client');
-
-This represents a MetaCPAN distribution entity.
+A MetaCPAN distribution entity object.
 
 =head1 ATTRIBUTES
 
 =head2 name
 
-Distribution's name.
-
 =head2 bugs
 
-Distribution's bug information.
+Hash-Ref.
 
 =head2 river
 
-Distribution's river information.
+Hash-Ref.
 
 =head1 AUTHORS
 
