@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::DownloadURL;
 # ABSTRACT: A Download URL data object
-$MetaCPAN::Client::DownloadURL::VERSION = '1.022000'; # TRIAL
+$MetaCPAN::Client::DownloadURL::VERSION = '1.025000'; # TRIAL
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -43,10 +43,18 @@ MetaCPAN::Client::DownloadURL - A Download URL data object
 
 =head1 VERSION
 
-version 1.022000
+version 1.025000
+
+=head1 SYNOPSIS
+
+my $download_url = $mcpan->download_url('Moose');
 
 =head1 DESCRIPTION
 
+A MetaCPAN download_url entiry object.
+
+Supported for MetaCPAN v1 only.
+
 =head1 ATTRIBUTES
 
 =head2 date
