@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Module;
 # ABSTRACT: A Module data object
-$MetaCPAN::Client::Module::VERSION = '1.022000'; # TRIAL
+$MetaCPAN::Client::Module::VERSION = '1.025000'; # TRIAL
 use Moo;
 extends 'MetaCPAN::Client::File';
 
@@ -20,10 +20,16 @@ MetaCPAN::Client::Module - A Module data object
 
 =head1 VERSION
 
-version 1.022000
+version 1.025000
+
+=head1 SYNOPSIS
+
+my $module = MetaCPAN::Client->new->module('Moo');
 
 =head1 DESCRIPTION
 
+A MetaCPAN module entity object.
+
 This is currently the exact same as L<MetaCPAN::Client::File>.
 
 =head1 ATTRIBUTES
