@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Rating;
 # ABSTRACT: A Rating data object
-$MetaCPAN::Client::Rating::VERSION = '1.022000'; # TRIAL
+$MetaCPAN::Client::Rating::VERSION = '1.025000'; # TRIAL
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -52,10 +52,16 @@ MetaCPAN::Client::Rating - A Rating data object
 
 =head1 VERSION
 
-version 1.022000
+version 1.025000
+
+=head1 SYNOPSIS
+
+my $rating = $mcpan->rating({ distribution => "Moo" });
 
 =head1 DESCRIPTION
 
+A MetaCPAN rating entity object.
+
 =head1 ATTRIBUTES
 
 =head2 date
